/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.api;

import java.awt.Image;
import java.awt.datatransfer.Transferable;
import java.awt.event.ActionEvent;
import java.io.Serializable;
import javax.swing.AbstractAction;
import javax.swing.Action;
import org.netbeans.api.project.Project;
import org.netbeans.core.api.multiview.MultiViews;
import org.netbeans.spi.project.ui.support.CommonProjectActions;
import org.openide.nodes.FilterNode;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;
import org.openide.util.datatransfer.PasteType;
import org.openide.util.lookup.Lookups;
import org.openide.util.lookup.ProxyLookup;
import org.openide.windows.TopComponent;

/**
 * Stock root node that appears under Farm-node
 * @author Gerben Feenstra
 */
public final class StockRootNode extends FilterNode implements Serializable {

    private static final String STOCK_NODE_NAME = "Stock";

    public StockRootNode(Node node, Project project) {
        super(node, Children.LEAF, new ProxyLookup(Lookups.singleton(project), node.getLookup()));
    }

    @Override
    public Action[] getActions(boolean arg0) {
        return new Action[]{
            new OpenStockDetailsAction()
        };
    }

    @Override
    public Image getIcon(int type) {
        return ImageUtilities.loadImage(Stock.STOCK_ICON16);
    }

    @Override
    public Image getOpenedIcon(int type) {
        return getIcon(type);
    }

    @Override
    public String getDisplayName() {
        return STOCK_NODE_NAME;
    }

    @Override
    public String getHtmlDisplayName() {
        return getDisplayName();
    }

    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.stock.about");
    }

    @Override
    public PasteType getDropType(Transferable t, int action, int index) {
        return null;
    }

    @NbBundle.Messages(value = "Stock open details action name=Open")
    private final class OpenStockDetailsAction extends AbstractAction {
        public OpenStockDetailsAction() {
            super(Bundle.Stock_open_details_action_name());
        }

        @Override
        public void actionPerformed(ActionEvent e) {
            TopComponent tc = MultiViews.createMultiView(Stock.MIME_TYPE, StockRootNode.this);
            tc.open();
            tc.requestActive();
        }
    }
}
