/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.api;

import java.io.IOException;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ui.support.NodeFactory;
import org.netbeans.spi.project.ui.support.NodeFactorySupport;
import org.netbeans.spi.project.ui.support.NodeList;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataFolder;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;

/**
 * NodeFactory registration for Farm projects Will search for STOCK_FOLDER_NAME
 * inside the specified (Farm) project
 *
 * @author Gerben Feenstra
 */
public class StockRootNodeFactory implements NodeFactory {

    @Override
    public NodeList createNodes(Project project) {

        FileObject stockFolder = getStockFolder(project);

        // Create Stock folder if it doesn't exist
        if (stockFolder == null) {
            try {
                stockFolder = project.getProjectDirectory().createFolder(Stock.STOCK_FOLDER_NAME);
            } catch (IOException ex) {
                Exceptions.printStackTrace(ex);
            }
        }
        assert (stockFolder != null);

        DataFolder stockDataFolder = DataFolder.findFolder(stockFolder);
        Node rootNode = new StockRootNode(stockDataFolder.getNodeDelegate(), project);
        return NodeFactorySupport.fixedNodeList(rootNode);
    }
    
    /**
     * Returns stockfolder inside the specified project
     * Protected for unittesting purposes!
     * @param project Project to get stockfolder from.
     * @return Stockfolder on the filesystem
     */
    protected FileObject getStockFolder(Project project){
        return project.getProjectDirectory().getFileObject(Stock.STOCK_FOLDER_NAME);
    }
}
